@@ -50,9 +50,8 @@ pub enum GovernanceInstruction {
     /// 5. `[]` System
     /// 6. `[]` SPL Token
     /// 7. `[]` Sysvar Rent
-    /// 8. `[]` Realm custodian - optional    
-    /// 9. `[]` Council Token Mint - optional
-    /// 10. `[writable]` Council Token Holding account - optional unless council is used. PDA seeds: ['governance',realm,council_mint]
+    /// 8. `[]` Council Token Mint - optional
+    /// 9. `[writable]` Council Token Holding account - optional unless council is used. PDA seeds: ['governance',realm,council_mint]
     ///     The account will be created with the Realm PDA as its owner
     CreateRealm {
         #[allow(dead_code)]
@@ -109,10 +108,11 @@ pub enum GovernanceInstruction {
     ///
     ///   0. `[]` Realm account the created Governance belongs to
     ///   1. `[writable]` Account Governance account. PDA seeds: ['account-governance', realm, governed_account]
-    ///   2. `[]` Account governed by this Governance account
-    ///   3. `[signer]` Payer
-    ///   4. `[]` System program
-    ///   5. `[]` Sysvar Rent
+    ///   2. `[]` Account governed by this Governance
+    ///   3. `[]` Governing TokenOwnerRecord account
+    ///   4. `[signer]` Payer
+    ///   5. `[]` System program
+    ///   6. `[]` Sysvar Rent
     CreateAccountGovernance {
         /// Governance config
         #[allow(dead_code)]
@@ -126,10 +126,11 @@ pub enum GovernanceInstruction {
     ///   2. `[]` Program governed by this Governance account
     ///   3. `[writable]` Program Data account of the Program governed by this Governance account
     ///   4. `[signer]` Current Upgrade Authority account of the Program governed by this Governance account
-    ///   5. `[signer]` Payer
-    ///   6. `[]` bpf_upgradeable_loader program
-    ///   7. `[]` System program
-    ///   8. `[]` Sysvar Rent
+    ///   5. `[]` Governing TokenOwnerRecord account     
+    ///   6. `[signer]` Payer
+    ///   7. `[]` bpf_upgradeable_loader program
+    ///   8. `[]` System program
+    ///   9. `[]` Sysvar Rent
     CreateProgramGovernance {
         /// Governance config
         #[allow(dead_code)]
@@ -147,7 +148,7 @@ pub enum GovernanceInstruction {
     ///   0. `[]` Realm account the created Proposal belongs to
     ///   1. `[writable]` Proposal account. PDA seeds ['governance',governance, governing_token_mint, proposal_index]
     ///   2. `[writable]` Governance account
-    ///   3. `[]` TokenOwnerRecord account for Proposal owner
+    ///   3. `[writable]` TokenOwnerRecord account of the Proposal owner
     ///   4. `[signer]` Governance Authority (Token Owner or Governance Delegate)
     ///   5. `[signer]` Payer
     ///   6. `[]` System program
@@ -170,7 +171,7 @@ pub enum GovernanceInstruction {
     /// Adds a signatory to the Proposal which means this Proposal can't leave Draft state until yet another Signatory signs
     ///
     ///   0. `[writable]` Proposal account
-    ///   1. `[]` TokenOwnerRecord account for Proposal owner
+    ///   1. `[]` TokenOwnerRecord account of the Proposal owner
     ///   2. `[signer]` Governance Authority (Token Owner or Governance Delegate)
     ///   3. `[writable]` Signatory Record Account
     ///   4. `[signer]` Payer
@@ -185,7 +186,7 @@ pub enum GovernanceInstruction {
     /// Removes a Signatory from the Proposal
     ///
     ///   0. `[writable]` Proposal account
-    ///   1. `[]` TokenOwnerRecord account for Proposal owner
+    ///   1. `[]` TokenOwnerRecord account of the Proposal owner
     ///   2. `[signer]` Governance Authority (Token Owner or Governance Delegate)
     ///   3. `[writable]` Signatory Record Account
     ///   4. `[writable]` Beneficiary Account which would receive lamports from the disposed Signatory Record Account
@@ -201,7 +202,7 @@ pub enum GovernanceInstruction {
 
     ///   0. `[]` Governance account
     ///   1. `[writable]` Proposal account
-    ///   2. `[]` TokenOwnerRecord account for Proposal owner
+    ///   2. `[]` TokenOwnerRecord account of the Proposal owner
     ///   3. `[signer]` Governance Authority (Token Owner or Governance Delegate)
     ///   4. `[writable]` ProposalInstruction account. PDA seeds: ['governance',proposal,index]
     ///   5. `[signer]` Payer
@@ -223,7 +224,7 @@ pub enum GovernanceInstruction {
     /// Removes instruction from the Proposal
     ///
     ///   0. `[writable]` Proposal account
-    ///   1. `[]` TokenOwnerRecord account for Proposal owner
+    ///   1. `[]` TokenOwnerRecord account of the Proposal owner
     ///   2. `[signer]` Governance Authority (Token Owner or Governance Delegate)
     ///   3. `[writable]` ProposalInstruction account
     ///   4. `[writable]` Beneficiary Account which would receive lamports from the disposed ProposalInstruction account
@@ -232,8 +233,8 @@ pub enum GovernanceInstruction {
     /// Cancels Proposal by changing its state to Canceled
     ///
     ///   0. `[writable]` Proposal account
-    ///   1. `[]`  TokenOwnerRecord account for Proposal owner
-    ///   2 `[signer]` Governance Authority (Token Owner or Governance Delegate)
+    ///   1. `[writable]`  TokenOwnerRecord account of the  Proposal owner
+    ///   2. `[signer]` Governance Authority (Token Owner or Governance Delegate)
     ///   3. `[]` Clock sysvar
     CancelProposal,
 
@@ -253,7 +254,8 @@ pub enum GovernanceInstruction {
     ///   0. `[]` Realm account
     ///   1. `[]` Governance account
     ///   2. `[writable]` Proposal account
-    ///   3. `[writable]` Token Owner Record account. PDA seeds: ['governance',realm, governing_token_mint, governing_token_owner]
+    ///   4. `[writable]` TokenOwnerRecord of the Proposal owner    
+    ///   3. `[writable]` TokenOwnerRecord of the voter. PDA seeds: ['governance',realm, governing_token_mint, governing_token_owner]
     ///   4. `[signer]` Governance Authority (Token Owner or Governance Delegate)
     ///   5. `[writable]` Proposal VoteRecord account. PDA seeds: ['governance',proposal,governing_token_owner_record]
     ///   6. `[]` Governing Token Mint
@@ -272,8 +274,9 @@ pub enum GovernanceInstruction {
     ///   0. `[]` Realm account    
     ///   1. `[]` Governance account
     ///   2. `[writable]` Proposal account
-    ///   3. `[]` Governing Token Mint
-    ///   4. `[]` Clock sysvar
+    ///   3. `[writable]` TokenOwnerRecord of the Proposal owner        
+    ///   4. `[]` Governing Token Mint
+    ///   5. `[]` Clock sysvar
     FinalizeVote {},
 
     ///  Relinquish Vote removes voter weight from a Proposal and removes it from voter's active votes
@@ -286,7 +289,6 @@ pub enum GovernanceInstruction {
     ///   2. `[writable]` TokenOwnerRecord account. PDA seeds: ['governance',realm, governing_token_mint, governing_token_owner]
     ///   3. `[writable]` Proposal VoteRecord account. PDA seeds: ['governance',proposal,governing_token_owner_record]
     ///   4. `[]` Governing Token Mint
-
     ///   5. `[signer]` Optional Governance Authority (Token Owner or Governance Delegate)
     ///       It's required only when Proposal is still being voted on
     ///   6. `[writable]` Optional Beneficiary account which would receive lamports when VoteRecord Account is disposed
@@ -310,10 +312,11 @@ pub enum GovernanceInstruction {
     ///   1. `[writable]` Mint Governance account. PDA seeds: ['mint-governance', realm, governed_mint]
     ///   2. `[writable]` Mint governed by this Governance account
     ///   3. `[signer]` Current Mint Authority
-    ///   4. `[signer]` Payer
-    ///   5. `[]` SPL Token program
-    ///   6. `[]` System program
-    ///   7. `[]` Sysvar Rent
+    ///   4. `[]` Governing TokenOwnerRecord account    
+    ///   5. `[signer]` Payer
+    ///   6. `[]` SPL Token program
+    ///   7. `[]` System program
+    ///   8. `[]` Sysvar Rent
     CreateMintGovernance {
         #[allow(dead_code)]
         /// Governance config
@@ -331,11 +334,12 @@ pub enum GovernanceInstruction {
     ///   0. `[]` Realm account the created Governance belongs to    
     ///   1. `[writable]` Token Governance account. PDA seeds: ['token-governance', realm, governed_token]
     ///   2. `[writable]` Token account governed by this Governance account
-    ///   3. `[signer]` Current Token account owner
-    ///   4. `[signer]` Payer
-    ///   5. `[]` SPL Token program
-    ///   6. `[]` System program
-    ///   7. `[]` Sysvar Rent
+    ///   3. `[signer]` Current Token account
+    ///   4. `[]` Governing TokenOwnerRecord account        
+    ///   5. `[signer]` Payer
+    ///   6. `[]` SPL Token program
+    ///   7. `[]` System program
+    ///   8. `[]` Sysvar Rent
     CreateTokenGovernance {
         #[allow(dead_code)]
         /// Governance config
@@ -364,7 +368,7 @@ pub enum GovernanceInstruction {
     ///       and the Governance program has no way to know when instruction failed and flag it automatically
     ///
     ///   0. `[writable]` Proposal account
-    ///   1. `[]` TokenOwnerRecord account for Proposal owner
+    ///   1. `[]` TokenOwnerRecord account of the Proposal owner
     ///   2. `[signer]` Governance Authority (Token Owner or Governance Delegate)    
     ///   3. `[writable]` ProposalInstruction account to flag
     ///   4. `[]` Clock sysvar
@@ -383,12 +387,11 @@ pub enum GovernanceInstruction {
     /// Sets realm config
     ///   0. `[writable]` Realm account
     ///   1. `[signer]`  Realm authority    
-    ///   2. `[]` Realm custodian - optional    
-    ///   3. `[]` Council Token Mint - optional
+    ///   2. `[]` Council Token Mint - optional
     ///       Note: In the current version it's only possible to remove council mint (set it to None)
     ///       After setting council to None it won't be possible to withdraw the tokens from the Realm any longer
     ///       If that's required then it must be done before executing this instruction
-    ///   4. `[writable]` Council Token Holding account - optional unless council is used. PDA seeds: ['governance',realm,council_mint]
+    ///   3. `[writable]` Council Token Holding account - optional unless council is used. PDA seeds: ['governance',realm,council_mint]
     ///       The account will be created with the Realm PDA as its owner
     SetRealmConfig {
         #[allow(dead_code)]
@@ -405,10 +408,10 @@ pub fn create_realm(
     realm_authority: &Pubkey,
     community_token_mint: &Pubkey,
     payer: &Pubkey,
-    realm_custodian: Option<Pubkey>,
     council_token_mint: Option<Pubkey>,
     // Args
     name: String,
+    min_community_tokens_to_create_governance: u64,
     community_mint_max_vote_weight_source: MintMaxVoteWeightSource,
 ) -> Instruction {
     let realm_address = get_realm_address(program_id, &name);
@@ -426,13 +429,6 @@ pub fn create_realm(
         AccountMeta::new_readonly(sysvar::rent::id(), false),
     ];
 
-    let use_custodian = if let Some(realm_custodian) = realm_custodian {
-        accounts.push(AccountMeta::new_readonly(realm_custodian, false));
-        true
-    } else {
-        false
-    };
-
     let use_council_mint = if let Some(council_token_mint) = council_token_mint {
         let council_token_holding_address =
             get_governing_token_holding_address(program_id, &realm_address, &council_token_mint);
@@ -447,7 +443,7 @@ pub fn create_realm(
     let instruction = GovernanceInstruction::CreateRealm {
         config_args: RealmConfigArgs {
             use_council_mint,
-            use_custodian,
+            min_community_tokens_to_create_governance,
             community_mint_max_vote_weight_source,
         },
         name,
@@ -582,6 +578,7 @@ pub fn create_account_governance(
     // Accounts
     realm: &Pubkey,
     governed_account: &Pubkey,
+    token_owner_record: &Pubkey,
     payer: &Pubkey,
     // Args
     config: GovernanceConfig,
@@ -593,6 +590,7 @@ pub fn create_account_governance(
         AccountMeta::new_readonly(*realm, false),
         AccountMeta::new(account_governance_address, false),
         AccountMeta::new_readonly(*governed_account, false),
+        AccountMeta::new_readonly(*token_owner_record, false),
         AccountMeta::new_readonly(*payer, true),
         AccountMeta::new_readonly(system_program::id(), false),
         AccountMeta::new_readonly(sysvar::rent::id(), false),
@@ -608,12 +606,14 @@ pub fn create_account_governance(
 }
 
 /// Creates CreateProgramGovernance instruction
+#[allow(clippy::too_many_arguments)]
 pub fn create_program_governance(
     program_id: &Pubkey,
     // Accounts
     realm: &Pubkey,
     governed_program: &Pubkey,
     governed_program_upgrade_authority: &Pubkey,
+    token_owner_record: &Pubkey,
     payer: &Pubkey,
     // Args
     config: GovernanceConfig,
@@ -629,6 +629,7 @@ pub fn create_program_governance(
         AccountMeta::new_readonly(*governed_program, false),
         AccountMeta::new(governed_program_data_address, false),
         AccountMeta::new_readonly(*governed_program_upgrade_authority, true),
+        AccountMeta::new_readonly(*token_owner_record, false),
         AccountMeta::new_readonly(*payer, true),
         AccountMeta::new_readonly(bpf_loader_upgradeable::id(), false),
         AccountMeta::new_readonly(system_program::id(), false),
@@ -647,13 +648,15 @@ pub fn create_program_governance(
     }
 }
 
-/// Creates CreateMintGovernance instruction
+/// Creates CreateMintGovernance
+#[allow(clippy::too_many_arguments)]
 pub fn create_mint_governance(
     program_id: &Pubkey,
     // Accounts
     realm: &Pubkey,
     governed_mint: &Pubkey,
     governed_mint_authority: &Pubkey,
+    token_owner_record: &Pubkey,
     payer: &Pubkey,
     // Args
     config: GovernanceConfig,
@@ -666,6 +669,7 @@ pub fn create_mint_governance(
         AccountMeta::new(mint_governance_address, false),
         AccountMeta::new(*governed_mint, false),
         AccountMeta::new_readonly(*governed_mint_authority, true),
+        AccountMeta::new_readonly(*token_owner_record, false),
         AccountMeta::new_readonly(*payer, true),
         AccountMeta::new_readonly(spl_token::id(), false),
         AccountMeta::new_readonly(system_program::id(), false),
@@ -685,12 +689,14 @@ pub fn create_mint_governance(
 }
 
 /// Creates CreateTokenGovernance instruction
+#[allow(clippy::too_many_arguments)]
 pub fn create_token_governance(
     program_id: &Pubkey,
     // Accounts
     realm: &Pubkey,
     governed_token: &Pubkey,
     governed_token_owner: &Pubkey,
+    token_owner_record: &Pubkey,
     payer: &Pubkey,
     // Args
     config: GovernanceConfig,
@@ -703,6 +709,7 @@ pub fn create_token_governance(
         AccountMeta::new(token_governance_address, false),
         AccountMeta::new(*governed_token, false),
         AccountMeta::new_readonly(*governed_token_owner, true),
+        AccountMeta::new_readonly(*token_owner_record, false),
         AccountMeta::new_readonly(*payer, true),
         AccountMeta::new_readonly(spl_token::id(), false),
         AccountMeta::new_readonly(system_program::id(), false),
@@ -727,7 +734,7 @@ pub fn create_proposal(
     program_id: &Pubkey,
     // Accounts
     governance: &Pubkey,
-    governing_token_owner_record: &Pubkey,
+    proposal_owner_record: &Pubkey,
     governance_authority: &Pubkey,
     payer: &Pubkey,
     // Args
@@ -748,7 +755,7 @@ pub fn create_proposal(
         AccountMeta::new_readonly(*realm, false),
         AccountMeta::new(proposal_address, false),
         AccountMeta::new(*governance, false),
-        AccountMeta::new_readonly(*governing_token_owner_record, false),
+        AccountMeta::new(*proposal_owner_record, false),
         AccountMeta::new_readonly(*governance_authority, true),
         AccountMeta::new_readonly(*payer, true),
         AccountMeta::new_readonly(system_program::id(), false),
@@ -867,20 +874,23 @@ pub fn cast_vote(
     realm: &Pubkey,
     governance: &Pubkey,
     proposal: &Pubkey,
-    token_owner_record: &Pubkey,
+    proposal_owner_record: &Pubkey,
+    voter_token_owner_record: &Pubkey,
     governance_authority: &Pubkey,
     governing_token_mint: &Pubkey,
     payer: &Pubkey,
     // Args
     vote: Vote,
 ) -> Instruction {
-    let vote_record_address = get_vote_record_address(program_id, proposal, token_owner_record);
+    let vote_record_address =
+        get_vote_record_address(program_id, proposal, voter_token_owner_record);
 
     let accounts = vec![
         AccountMeta::new_readonly(*realm, false),
         AccountMeta::new_readonly(*governance, false),
         AccountMeta::new(*proposal, false),
-        AccountMeta::new(*token_owner_record, false),
+        AccountMeta::new(*proposal_owner_record, false),
+        AccountMeta::new(*voter_token_owner_record, false),
         AccountMeta::new_readonly(*governance_authority, true),
         AccountMeta::new(vote_record_address, false),
         AccountMeta::new_readonly(*governing_token_mint, false),
@@ -906,12 +916,14 @@ pub fn finalize_vote(
     realm: &Pubkey,
     governance: &Pubkey,
     proposal: &Pubkey,
+    proposal_owner_record: &Pubkey,
     governing_token_mint: &Pubkey,
 ) -> Instruction {
     let accounts = vec![
         AccountMeta::new_readonly(*realm, false),
         AccountMeta::new_readonly(*governance, false),
         AccountMeta::new(*proposal, false),
+        AccountMeta::new(*proposal_owner_record, false),
         AccountMeta::new_readonly(*governing_token_mint, false),
         AccountMeta::new_readonly(sysvar::clock::id(), false),
     ];
@@ -965,12 +977,12 @@ pub fn cancel_proposal(
     program_id: &Pubkey,
     // Accounts
     proposal: &Pubkey,
-    token_owner_record: &Pubkey,
+    proposal_owner_record: &Pubkey,
     governance_authority: &Pubkey,
 ) -> Instruction {
     let accounts = vec![
         AccountMeta::new(*proposal, false),
-        AccountMeta::new_readonly(*token_owner_record, false),
+        AccountMeta::new(*proposal_owner_record, false),
         AccountMeta::new_readonly(*governance_authority, true),
         AccountMeta::new_readonly(sysvar::clock::id(), false),
     ];
@@ -1159,8 +1171,9 @@ pub fn set_realm_config(
     realm: &Pubkey,
     realm_authority: &Pubkey,
     council_token_mint: Option<Pubkey>,
-    realm_custodian: Option<Pubkey>,
+
     // Args
+    min_community_tokens_to_create_governance: u64,
     community_mint_max_vote_weight_source: MintMaxVoteWeightSource,
 ) -> Instruction {
     let mut accounts = vec![
@@ -1168,13 +1181,6 @@ pub fn set_realm_config(
         AccountMeta::new_readonly(*realm_authority, true),
     ];
 
-    let use_custodian = if let Some(realm_custodian) = realm_custodian {
-        accounts.push(AccountMeta::new_readonly(realm_custodian, false));
-        true
-    } else {
-        false
-    };
-
     let use_council_mint = if let Some(council_token_mint) = council_token_mint {
         let council_token_holding_address =
             get_governing_token_holding_address(program_id, realm, &council_token_mint);
@@ -1189,7 +1195,7 @@ pub fn set_realm_config(
     let instruction = GovernanceInstruction::SetRealmConfig {
         config_args: RealmConfigArgs {
             use_council_mint,
-            use_custodian,
+            min_community_tokens_to_create_governance,
             community_mint_max_vote_weight_source,
         },
     };
