@@ -7,6 +7,8 @@ use crate::{
             assert_valid_create_governance_args, get_mint_governance_address_seeds, Governance,
             GovernanceConfig,
         },
+        realm::get_realm_data,
+        token_owner_record::get_token_owner_record_data_for_realm,
     },
     tools::{
         account::create_and_serialize_account_signed,
@@ -36,16 +38,24 @@ pub fn process_create_mint_governance(
     let governed_mint_info = next_account_info(account_info_iter)?; // 2
     let governed_mint_authority_info = next_account_info(account_info_iter)?; // 3
 
-    let payer_info = next_account_info(account_info_iter)?; // 4
-    let spl_token_info = next_account_info(account_info_iter)?; // 5
+    let token_owner_record_info = next_account_info(account_info_iter)?; // 4
 
-    let system_info = next_account_info(account_info_iter)?; // 6
+    let payer_info = next_account_info(account_info_iter)?; // 5
+    let spl_token_info = next_account_info(account_info_iter)?; // 6
 
-    let rent_sysvar_info = next_account_info(account_info_iter)?; // 7
+    let system_info = next_account_info(account_info_iter)?; // 7
+
+    let rent_sysvar_info = next_account_info(account_info_iter)?; // 8
     let rent = &Rent::from_account_info(rent_sysvar_info)?;
 
     assert_valid_create_governance_args(program_id, &config, realm_info)?;
 
+    let realm_data = get_realm_data(program_id, realm_info)?;
+    let token_owner_record_data =
+        get_token_owner_record_data_for_realm(program_id, token_owner_record_info, realm_info.key)?;
+
+    token_owner_record_data.assert_can_create_governance(&realm_data)?;
+
     let mint_governance_data = Governance {
         account_type: GovernanceAccountType::MintGovernance,
         realm: *realm_info.key,
