@@ -13,6 +13,7 @@ use crate::{
         governance::get_governance_data_for_realm,
         proposal::get_proposal_data_for_governance_and_governing_mint,
         realm::get_realm_data_for_governing_token_mint,
+        token_owner_record::get_token_owner_record_data_for_proposal_owner,
     },
     tools::spl_token::get_spl_token_mint_supply,
 };
@@ -26,10 +27,11 @@ pub fn process_finalize_vote(program_id: &Pubkey, accounts: &[AccountInfo]) -> P
     let realm_info = next_account_info(account_info_iter)?; // 0
     let governance_info = next_account_info(account_info_iter)?; // 1
     let proposal_info = next_account_info(account_info_iter)?; // 2
+    let proposal_owner_record_info = next_account_info(account_info_iter)?; // 3
 
-    let governing_token_mint_info = next_account_info(account_info_iter)?; // 3
+    let governing_token_mint_info = next_account_info(account_info_iter)?; // 4
 
-    let clock_info = next_account_info(account_info_iter)?; // 4
+    let clock_info = next_account_info(account_info_iter)?; // 5
     let clock = Clock::from_account_info(clock_info)?;
 
     let realm_data = get_realm_data_for_governing_token_mint(
@@ -58,5 +60,13 @@ pub fn process_finalize_vote(program_id: &Pubkey, accounts: &[AccountInfo]) -> P
 
     proposal_data.serialize(&mut *proposal_info.data.borrow_mut())?;
 
+    let mut proposal_owner_record_data = get_token_owner_record_data_for_proposal_owner(
+        program_id,
+        proposal_owner_record_info,
+        &proposal_data.token_owner_record,
+    )?;
+    proposal_owner_record_data.decrease_outstanding_proposal_count();
+    proposal_owner_record_data.serialize(&mut *proposal_owner_record_info.data.borrow_mut())?;
+
     Ok(())
 }
