@@ -162,14 +162,23 @@ pub enum InstructionExecutionFlags {
 
 /// The source of max vote weight used for voting
 /// Values below 100% mint supply can be used when the governing token is fully minted but not distributed yet
-/// Note: This field is not used yet. It's reserved for future versions
 #[repr(C)]
 #[derive(Clone, Debug, PartialEq, BorshDeserialize, BorshSerialize, BorshSchema)]
 pub enum MintMaxVoteWeightSource {
-    /// Percentage of the governing mint supply is used as max vote weight
-    /// The default is 100% to use all available mint supply for voting
-    Percentage(u8),
+    /// Fraction (10^10 precision) of the governing mint supply is used as max vote weight
+    /// The default is 100% (10^10) to use all available mint supply for voting
+    SupplyFraction(u64),
 
     /// Absolute value, irrelevant of the actual mint supply, is used as max vote weight
+    /// Note: this option is not implemented in the current version
     Absolute(u64),
 }
+
+impl MintMaxVoteWeightSource {
+    /// Base for mint supply fraction calculation
+    pub const SUPPLY_FRACTION_BASE: u64 = 10_000_000_000;
+
+    /// 100% of mint supply
+    pub const FULL_SUPPLY_FRACTION: MintMaxVoteWeightSource =
+        MintMaxVoteWeightSource::SupplyFraction(MintMaxVoteWeightSource::SUPPLY_FRACTION_BASE);
+}
