@@ -280,7 +280,9 @@ impl Proposal {
 
                 Ok(max_vote_weight.max(total_vote_count))
             }
-            _ => Err(GovernanceError::VoteWeightSourceNotSupported.into()),
+            MintMaxVoteWeightSource::Absolute(_) => {
+                Err(GovernanceError::VoteWeightSourceNotSupported.into())
+            }
         }
     }
 
@@ -292,7 +294,7 @@ impl Proposal {
         config: &GovernanceConfig,
         realm_data: &Realm,
         current_unix_timestamp: UnixTimestamp,
-    ) -> Result<(), ProgramError> {
+    ) -> Result<bool, ProgramError> {
         let max_vote_weight = self.get_max_vote_weight(realm_data, governing_token_mint_supply)?;
 
         if let Some(tipped_state) = self.try_get_tipped_vote_state(max_vote_weight, config) {
@@ -302,9 +304,11 @@ impl Proposal {
             // Capture vote params to correctly display historical results
             self.max_vote_weight = Some(max_vote_weight);
             self.vote_threshold_percentage = Some(config.vote_threshold_percentage.clone());
-        }
 
-        Ok(())
+            Ok(true)
+        } else {
+            Ok(false)
+        }
     }
 
     /// Checks if vote can be tipped and automatically transitioned to Succeeded or Defeated state
@@ -562,9 +566,10 @@ mod test {
             config: RealmConfig {
                 council_mint: Some(Pubkey::new_unique()),
                 reserved: [0; 8],
-                custodian: Some(Pubkey::new_unique()),
+
                 community_mint_max_vote_weight_source:
                     MintMaxVoteWeightSource::FULL_SUPPLY_FRACTION,
+                min_community_tokens_to_create_governance: 10,
             },
         }
     }
