@@ -17,9 +17,17 @@ async fn test_create_program_governance() {
     let realm_cookie = governance_test.with_realm().await;
     let governed_program_cookie = governance_test.with_governed_program().await;
 
+    let token_owner_record_cookie = governance_test
+        .with_community_token_deposit(&realm_cookie)
+        .await;
+
     // Act
     let program_governance_cookie = governance_test
-        .with_program_governance(&realm_cookie, &governed_program_cookie)
+        .with_program_governance(
+            &realm_cookie,
+            &governed_program_cookie,
+            &token_owner_record_cookie,
+        )
         .await
         .unwrap();
 
@@ -50,11 +58,19 @@ async fn test_create_program_governance_without_transferring_upgrade_authority()
     let realm_cookie = governance_test.with_realm().await;
     let mut governed_program_cookie = governance_test.with_governed_program().await;
 
+    let token_owner_record_cookie = governance_test
+        .with_community_token_deposit(&realm_cookie)
+        .await;
+
     governed_program_cookie.transfer_upgrade_authority = false;
 
     // Act
     let program_governance_cookie = governance_test
-        .with_program_governance(&realm_cookie, &governed_program_cookie)
+        .with_program_governance(
+            &realm_cookie,
+            &governed_program_cookie,
+            &token_owner_record_cookie,
+        )
         .await
         .unwrap();
 
@@ -89,12 +105,20 @@ async fn test_create_program_governance_without_transferring_upgrade_authority_w
     let realm_cookie = governance_test.with_realm().await;
     let mut governed_program_cookie = governance_test.with_governed_program().await;
 
+    let token_owner_record_cookie = governance_test
+        .with_community_token_deposit(&realm_cookie)
+        .await;
+
     governed_program_cookie.transfer_upgrade_authority = false;
     governed_program_cookie.upgrade_authority = Keypair::new();
 
     // Act
     let err = governance_test
-        .with_program_governance(&realm_cookie, &governed_program_cookie)
+        .with_program_governance(
+            &realm_cookie,
+            &governed_program_cookie,
+            &token_owner_record_cookie,
+        )
         .await
         .err()
         .unwrap();
@@ -112,6 +136,10 @@ async fn test_create_program_governance_without_transferring_upgrade_authority_w
     let realm_cookie = governance_test.with_realm().await;
     let mut governed_program_cookie = governance_test.with_governed_program().await;
 
+    let token_owner_record_cookie = governance_test
+        .with_community_token_deposit(&realm_cookie)
+        .await;
+
     governed_program_cookie.transfer_upgrade_authority = false;
 
     // Act
@@ -119,6 +147,7 @@ async fn test_create_program_governance_without_transferring_upgrade_authority_w
         .with_program_governance_using_instruction(
             &realm_cookie,
             &governed_program_cookie,
+            &token_owner_record_cookie,
             |i| {
                 i.accounts[4].is_signer = false; // governed_program_upgrade_authority
             },
@@ -140,11 +169,19 @@ async fn test_create_program_governance_with_incorrect_upgrade_authority_error()
     let realm_cookie = governance_test.with_realm().await;
     let mut governed_program_cookie = governance_test.with_governed_program().await;
 
+    let token_owner_record_cookie = governance_test
+        .with_community_token_deposit(&realm_cookie)
+        .await;
+
     governed_program_cookie.upgrade_authority = Keypair::new();
 
     // Act
     let err = governance_test
-        .with_program_governance(&realm_cookie, &governed_program_cookie)
+        .with_program_governance(
+            &realm_cookie,
+            &governed_program_cookie,
+            &token_owner_record_cookie,
+        )
         .await
         .err()
         .unwrap();
@@ -161,8 +198,16 @@ async fn test_create_program_governance_with_invalid_realm_error() {
     let mut realm_cookie = governance_test.with_realm().await;
     let governed_program_cookie = governance_test.with_governed_program().await;
 
+    let token_owner_record_cookie = governance_test
+        .with_community_token_deposit(&realm_cookie)
+        .await;
+
     let program_governance_cookie = governance_test
-        .with_program_governance(&realm_cookie, &governed_program_cookie)
+        .with_program_governance(
+            &realm_cookie,
+            &governed_program_cookie,
+            &token_owner_record_cookie,
+        )
         .await
         .unwrap();
 
@@ -170,7 +215,11 @@ async fn test_create_program_governance_with_invalid_realm_error() {
 
     // Act
     let err = governance_test
-        .with_program_governance(&realm_cookie, &governed_program_cookie)
+        .with_program_governance(
+            &realm_cookie,
+            &governed_program_cookie,
+            &token_owner_record_cookie,
+        )
         .await
         .err()
         .unwrap();
