@@ -1,4 +1,4 @@
-#![cfg(feature = "test-bpf")]
+#![cfg(feature = "test-bpf-all")]
 
 mod program_test;
 
@@ -24,15 +24,19 @@ async fn test_execute_mint_instruction() {
     let realm_cookie = governance_test.with_realm().await;
     let governed_mint_cookie = governance_test.with_governed_mint().await;
 
-    let mut mint_governance_cookie = governance_test
-        .with_mint_governance(&realm_cookie, &governed_mint_cookie)
-        .await
-        .unwrap();
-
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
         .await;
 
+    let mut mint_governance_cookie = governance_test
+        .with_mint_governance(
+            &realm_cookie,
+            &governed_mint_cookie,
+            &token_owner_record_cookie,
+        )
+        .await
+        .unwrap();
+
     let mut proposal_cookie = governance_test
         .with_proposal(&token_owner_record_cookie, &mut mint_governance_cookie)
         .await
@@ -116,15 +120,19 @@ async fn test_execute_transfer_instruction() {
     let realm_cookie = governance_test.with_realm().await;
     let governed_token_cookie = governance_test.with_governed_token().await;
 
-    let mut token_governance_cookie = governance_test
-        .with_token_governance(&realm_cookie, &governed_token_cookie)
-        .await
-        .unwrap();
-
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
         .await;
 
+    let mut token_governance_cookie = governance_test
+        .with_token_governance(
+            &realm_cookie,
+            &governed_token_cookie,
+            &token_owner_record_cookie,
+        )
+        .await
+        .unwrap();
+
     let mut proposal_cookie = governance_test
         .with_proposal(&token_owner_record_cookie, &mut token_governance_cookie)
         .await
@@ -208,15 +216,19 @@ async fn test_execute_upgrade_program_instruction() {
     let realm_cookie = governance_test.with_realm().await;
     let governed_program_cookie = governance_test.with_governed_program().await;
 
-    let mut program_governance_cookie = governance_test
-        .with_program_governance(&realm_cookie, &governed_program_cookie)
-        .await
-        .unwrap();
-
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
         .await;
 
+    let mut program_governance_cookie = governance_test
+        .with_program_governance(
+            &realm_cookie,
+            &governed_program_cookie,
+            &token_owner_record_cookie,
+        )
+        .await
+        .unwrap();
+
     let mut proposal_cookie = governance_test
         .with_proposal(&token_owner_record_cookie, &mut program_governance_cookie)
         .await
@@ -328,15 +340,19 @@ async fn test_execute_instruction_with_invalid_state_errors() {
     let realm_cookie = governance_test.with_realm().await;
     let governed_mint_cookie = governance_test.with_governed_mint().await;
 
-    let mut mint_governance_cookie = governance_test
-        .with_mint_governance(&realm_cookie, &governed_mint_cookie)
-        .await
-        .unwrap();
-
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
         .await;
 
+    let mut mint_governance_cookie = governance_test
+        .with_mint_governance(
+            &realm_cookie,
+            &governed_mint_cookie,
+            &token_owner_record_cookie,
+        )
+        .await
+        .unwrap();
+
     let mut proposal_cookie = governance_test
         .with_proposal(&token_owner_record_cookie, &mut mint_governance_cookie)
         .await
@@ -486,15 +502,19 @@ async fn test_execute_instruction_for_other_proposal_error() {
     let realm_cookie = governance_test.with_realm().await;
     let governed_mint_cookie = governance_test.with_governed_mint().await;
 
-    let mut mint_governance_cookie = governance_test
-        .with_mint_governance(&realm_cookie, &governed_mint_cookie)
-        .await
-        .unwrap();
-
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
         .await;
 
+    let mut mint_governance_cookie = governance_test
+        .with_mint_governance(
+            &realm_cookie,
+            &governed_mint_cookie,
+            &token_owner_record_cookie,
+        )
+        .await
+        .unwrap();
+
     let mut proposal_cookie = governance_test
         .with_proposal(&token_owner_record_cookie, &mut mint_governance_cookie)
         .await
@@ -531,8 +551,12 @@ async fn test_execute_instruction_for_other_proposal_error() {
         .advance_clock_by_min_timespan(proposal_instruction_cookie.account.hold_up_time as u64)
         .await;
 
+    let token_owner_record_cookie2 = governance_test
+        .with_community_token_deposit(&realm_cookie)
+        .await;
+
     let proposal_cookie2 = governance_test
-        .with_proposal(&token_owner_record_cookie, &mut mint_governance_cookie)
+        .with_proposal(&token_owner_record_cookie2, &mut mint_governance_cookie)
         .await
         .unwrap();
 
@@ -558,15 +582,19 @@ async fn test_execute_mint_instruction_twice_error() {
     let realm_cookie = governance_test.with_realm().await;
     let governed_mint_cookie = governance_test.with_governed_mint().await;
 
-    let mut mint_governance_cookie = governance_test
-        .with_mint_governance(&realm_cookie, &governed_mint_cookie)
-        .await
-        .unwrap();
-
     let token_owner_record_cookie = governance_test
         .with_community_token_deposit(&realm_cookie)
         .await;
 
+    let mut mint_governance_cookie = governance_test
+        .with_mint_governance(
+            &realm_cookie,
+            &governed_mint_cookie,
+            &token_owner_record_cookie,
+        )
+        .await
+        .unwrap();
+
     let mut proposal_cookie = governance_test
         .with_proposal(&token_owner_record_cookie, &mut mint_governance_cookie)
         .await
