@@ -65,7 +65,7 @@ use self::{
     cookies::{
         GovernanceCookie, GovernedAccountCookie, GovernedMintCookie, GovernedProgramCookie,
         GovernedTokenCookie, ProposalCookie, ProposalInstructionCookie, RealmCookie,
-        TokeOwnerRecordCookie, TokenAccountCookie, VoteRecordCookie,
+        TokenAccountCookie, TokenOwnerRecordCookie, VoteRecordCookie,
     },
     tools::NopOverride,
 };
@@ -137,8 +137,9 @@ impl GovernanceProgramTest {
     pub async fn with_realm(&mut self) -> RealmCookie {
         let config_args = RealmConfigArgs {
             use_council_mint: true,
-            use_custodian: true,
+
             community_mint_max_vote_weight_source: MintMaxVoteWeightSource::FULL_SUPPLY_FRACTION,
+            min_community_tokens_to_create_governance: 10,
         };
 
         self.with_realm_using_config_args(&config_args).await
@@ -199,16 +200,15 @@ impl GovernanceProgramTest {
         };
 
         let realm_authority = Keypair::new();
-        let realm_custodian = Keypair::new();
 
         let create_realm_instruction = create_realm(
             &self.program_id,
             &realm_authority.pubkey(),
             &community_token_mint_keypair.pubkey(),
             &self.context.payer.pubkey(),
-            Some(realm_custodian.pubkey()),
             council_token_mint_pubkey,
             name.clone(),
+            config_args.min_community_tokens_to_create_governance,
             config_args.community_mint_max_vote_weight_source.clone(),
         );
 
@@ -226,7 +226,9 @@ impl GovernanceProgramTest {
             config: RealmConfig {
                 council_mint: council_token_mint_pubkey,
                 reserved: [0; 8],
-                custodian: Some(realm_custodian.pubkey()),
+
+                min_community_tokens_to_create_governance: config_args
+                    .min_community_tokens_to_create_governance,
                 community_mint_max_vote_weight_source: config_args
                     .community_mint_max_vote_weight_source
                     .clone(),
@@ -255,17 +257,18 @@ impl GovernanceProgramTest {
         let council_mint = realm_cookie.account.config.council_mint.unwrap();
 
         let realm_authority = Keypair::new();
-        let realm_custodian = Keypair::new();
+
         let community_mint_max_vote_weight_source = MintMaxVoteWeightSource::FULL_SUPPLY_FRACTION;
+        let min_community_tokens_to_create_governance = 10;
 
         let create_realm_instruction = create_realm(
             &self.program_id,
             &realm_authority.pubkey(),
             &realm_cookie.account.community_mint,
             &self.context.payer.pubkey(),
-            Some(realm_custodian.pubkey()),
             Some(council_mint),
             name.clone(),
+            min_community_tokens_to_create_governance,
             community_mint_max_vote_weight_source,
         );
 
@@ -283,9 +286,10 @@ impl GovernanceProgramTest {
             config: RealmConfig {
                 council_mint: Some(council_mint),
                 reserved: [0; 8],
-                custodian: Some(realm_authority.pubkey()),
+
                 community_mint_max_vote_weight_source:
                     MintMaxVoteWeightSource::FULL_SUPPLY_FRACTION,
+                min_community_tokens_to_create_governance,
             },
         };
 
@@ -317,7 +321,7 @@ impl GovernanceProgramTest {
     pub async fn with_community_token_deposit(
         &mut self,
         realm_cookie: &RealmCookie,
-    ) -> TokeOwnerRecordCookie {
+    ) -> TokenOwnerRecordCookie {
         self.with_initial_governing_token_deposit(
             &realm_cookie.address,
             &realm_cookie.account.community_mint,
@@ -332,7 +336,7 @@ impl GovernanceProgramTest {
         &mut self,
         realm_cookie: &RealmCookie,
         amount: u64,
-    ) -> TokeOwnerRecordCookie {
+    ) -> TokenOwnerRecordCookie {
         self.with_initial_governing_token_deposit(
             &realm_cookie.address,
             &realm_cookie.account.community_mint,
@@ -346,7 +350,7 @@ impl GovernanceProgramTest {
     pub async fn with_subsequent_community_token_deposit(
         &mut self,
         realm_cookie: &RealmCookie,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
         amount: u64,
     ) {
         self.with_subsequent_governing_token_deposit(
@@ -363,7 +367,7 @@ impl GovernanceProgramTest {
     pub async fn with_subsequent_council_token_deposit(
         &mut self,
         realm_cookie: &RealmCookie,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
         amount: u64,
     ) {
         self.with_subsequent_governing_token_deposit(
@@ -381,7 +385,7 @@ impl GovernanceProgramTest {
         &mut self,
         realm_cookie: &RealmCookie,
         amount: u64,
-    ) -> TokeOwnerRecordCookie {
+    ) -> TokenOwnerRecordCookie {
         self.with_initial_governing_token_deposit(
             &realm_cookie.address,
             &realm_cookie.account.config.council_mint.unwrap(),
@@ -395,7 +399,7 @@ impl GovernanceProgramTest {
     pub async fn with_council_token_deposit(
         &mut self,
         realm_cookie: &RealmCookie,
-    ) -> TokeOwnerRecordCookie {
+    ) -> TokenOwnerRecordCookie {
         self.with_initial_governing_token_deposit(
             &realm_cookie.address,
             &realm_cookie.account.config.council_mint.unwrap(),
@@ -412,7 +416,7 @@ impl GovernanceProgramTest {
         governing_mint: &Pubkey,
         governing_mint_authority: &Keypair,
         amount: u64,
-    ) -> TokeOwnerRecordCookie {
+    ) -> TokenOwnerRecordCookie {
         let token_owner = Keypair::new();
         let token_source = Keypair::new();
 
@@ -461,12 +465,13 @@ impl GovernanceProgramTest {
             governance_delegate: None,
             unrelinquished_votes_count: 0,
             total_votes_count: 0,
-            reserved: [0; 8],
+            outstanding_proposal_count: 0,
+            reserved: [0; 7],
         };
 
         let governance_delegate = Keypair::from_base58_string(&token_owner.to_base58_string());
 
-        TokeOwnerRecordCookie {
+        TokenOwnerRecordCookie {
             address: token_owner_record_address,
             account,
 
@@ -504,7 +509,7 @@ impl GovernanceProgramTest {
         realm: &Pubkey,
         governing_token_mint: &Pubkey,
         governing_token_mint_authority: &Keypair,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
         amount: u64,
     ) {
         self.mint_tokens(
@@ -537,7 +542,7 @@ impl GovernanceProgramTest {
     pub async fn with_community_governance_delegate(
         &mut self,
         realm_cookie: &RealmCookie,
-        token_owner_record_cookie: &mut TokeOwnerRecordCookie,
+        token_owner_record_cookie: &mut TokenOwnerRecordCookie,
     ) {
         self.with_governing_token_governance_delegate(
             realm_cookie,
@@ -551,7 +556,7 @@ impl GovernanceProgramTest {
     pub async fn with_council_governance_delegate(
         &mut self,
         realm_cookie: &RealmCookie,
-        token_owner_record_cookie: &mut TokeOwnerRecordCookie,
+        token_owner_record_cookie: &mut TokenOwnerRecordCookie,
     ) {
         self.with_governing_token_governance_delegate(
             realm_cookie,
@@ -566,7 +571,7 @@ impl GovernanceProgramTest {
         &mut self,
         realm_cookie: &RealmCookie,
         governing_token_mint: &Pubkey,
-        token_owner_record_cookie: &mut TokeOwnerRecordCookie,
+        token_owner_record_cookie: &mut TokenOwnerRecordCookie,
     ) {
         let new_governance_delegate = Keypair::new();
 
@@ -586,7 +591,7 @@ impl GovernanceProgramTest {
     pub async fn set_governance_delegate(
         &mut self,
         realm_cookie: &RealmCookie,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
         signing_governance_authority: &Keypair,
         governing_token_mint: &Pubkey,
         new_governance_delegate: &Option<Pubkey>,
@@ -671,19 +676,12 @@ impl GovernanceProgramTest {
             None
         };
 
-        let realm_custodian = if config_args.use_custodian {
-            let realm_custodian = Keypair::new();
-            Some(realm_custodian.pubkey())
-        } else {
-            None
-        };
-
         let mut set_realm_config_ix = set_realm_config(
             &self.program_id,
             &realm_cookie.address,
             &realm_cookie.realm_authority.as_ref().unwrap().pubkey(),
             council_token_mint,
-            realm_custodian,
+            config_args.min_community_tokens_to_create_governance,
             config_args.community_mint_max_vote_weight_source.clone(),
         );
 
@@ -692,7 +690,6 @@ impl GovernanceProgramTest {
         let default_signers = &[realm_cookie.realm_authority.as_ref().unwrap()];
         let signers = signers_override.unwrap_or(default_signers);
 
-        realm_cookie.account.config.custodian = realm_custodian;
         realm_cookie.account.config.council_mint = council_token_mint;
         realm_cookie
             .account
@@ -708,7 +705,7 @@ impl GovernanceProgramTest {
     pub async fn withdraw_community_tokens(
         &mut self,
         realm_cookie: &RealmCookie,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
     ) -> Result<(), ProgramError> {
         self.withdraw_governing_tokens(
             realm_cookie,
@@ -723,7 +720,7 @@ impl GovernanceProgramTest {
     pub async fn withdraw_council_tokens(
         &mut self,
         realm_cookie: &RealmCookie,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
     ) -> Result<(), ProgramError> {
         self.withdraw_governing_tokens(
             realm_cookie,
@@ -738,7 +735,7 @@ impl GovernanceProgramTest {
     async fn withdraw_governing_tokens(
         &mut self,
         realm_cookie: &RealmCookie,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
         governing_token_mint: &Pubkey,
 
         governing_token_owner: &Keypair,
@@ -831,10 +828,16 @@ impl GovernanceProgramTest {
         &mut self,
         realm_cookie: &RealmCookie,
         governed_account_cookie: &GovernedAccountCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
     ) -> Result<GovernanceCookie, ProgramError> {
         let config = self.get_default_governance_config();
-        self.with_account_governance_using_config(realm_cookie, governed_account_cookie, &config)
-            .await
+        self.with_account_governance_using_config(
+            realm_cookie,
+            governed_account_cookie,
+            token_owner_record_cookie,
+            &config,
+        )
+        .await
     }
 
     #[allow(dead_code)]
@@ -842,12 +845,14 @@ impl GovernanceProgramTest {
         &mut self,
         realm_cookie: &RealmCookie,
         governed_account_cookie: &GovernedAccountCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
         governance_config: &GovernanceConfig,
     ) -> Result<GovernanceCookie, ProgramError> {
         let create_account_governance_instruction = create_account_governance(
             &self.program_id,
             &realm_cookie.address,
             &governed_account_cookie.address,
+            &token_owner_record_cookie.address,
             &self.context.payer.pubkey(),
             governance_config.clone(),
         );
@@ -953,10 +958,12 @@ impl GovernanceProgramTest {
         &mut self,
         realm_cookie: &RealmCookie,
         governed_program_cookie: &GovernedProgramCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
     ) -> Result<GovernanceCookie, ProgramError> {
         self.with_program_governance_using_instruction(
             realm_cookie,
             governed_program_cookie,
+            token_owner_record_cookie,
             NopOverride,
             None,
         )
@@ -968,6 +975,7 @@ impl GovernanceProgramTest {
         &mut self,
         realm_cookie: &RealmCookie,
         governed_program_cookie: &GovernedProgramCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
         instruction_override: F,
         signers_override: Option<&[&Keypair]>,
     ) -> Result<GovernanceCookie, ProgramError> {
@@ -978,6 +986,7 @@ impl GovernanceProgramTest {
             &realm_cookie.address,
             &governed_program_cookie.address,
             &governed_program_cookie.upgrade_authority.pubkey(),
+            &token_owner_record_cookie.address,
             &self.context.payer.pubkey(),
             config.clone(),
             governed_program_cookie.transfer_upgrade_authority,
@@ -1018,10 +1027,12 @@ impl GovernanceProgramTest {
         &mut self,
         realm_cookie: &RealmCookie,
         governed_mint_cookie: &GovernedMintCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
     ) -> Result<GovernanceCookie, ProgramError> {
         self.with_mint_governance_using_instruction(
             realm_cookie,
             governed_mint_cookie,
+            token_owner_record_cookie,
             NopOverride,
             None,
         )
@@ -1033,6 +1044,7 @@ impl GovernanceProgramTest {
         &mut self,
         realm_cookie: &RealmCookie,
         governed_mint_cookie: &GovernedMintCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
         instruction_override: F,
         signers_override: Option<&[&Keypair]>,
     ) -> Result<GovernanceCookie, ProgramError> {
@@ -1043,6 +1055,7 @@ impl GovernanceProgramTest {
             &realm_cookie.address,
             &governed_mint_cookie.address,
             &governed_mint_cookie.mint_authority.pubkey(),
+            &token_owner_record_cookie.address,
             &self.context.payer.pubkey(),
             config.clone(),
             governed_mint_cookie.transfer_mint_authority,
@@ -1083,10 +1096,12 @@ impl GovernanceProgramTest {
         &mut self,
         realm_cookie: &RealmCookie,
         governed_token_cookie: &GovernedTokenCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
     ) -> Result<GovernanceCookie, ProgramError> {
         self.with_token_governance_using_instruction(
             realm_cookie,
             governed_token_cookie,
+            &token_owner_record_cookie,
             NopOverride,
             None,
         )
@@ -1098,6 +1113,7 @@ impl GovernanceProgramTest {
         &mut self,
         realm_cookie: &RealmCookie,
         governed_token_cookie: &GovernedTokenCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
         instruction_override: F,
         signers_override: Option<&[&Keypair]>,
     ) -> Result<GovernanceCookie, ProgramError> {
@@ -1108,6 +1124,7 @@ impl GovernanceProgramTest {
             &realm_cookie.address,
             &governed_token_cookie.address,
             &governed_token_cookie.token_owner.pubkey(),
+            &token_owner_record_cookie.address,
             &self.context.payer.pubkey(),
             config.clone(),
             governed_token_cookie.transfer_token_owner,
@@ -1146,7 +1163,7 @@ impl GovernanceProgramTest {
     #[allow(dead_code)]
     pub async fn with_proposal(
         &mut self,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
         governance_cookie: &mut GovernanceCookie,
     ) -> Result<ProposalCookie, ProgramError> {
         self.with_proposal_using_instruction(
@@ -1160,7 +1177,7 @@ impl GovernanceProgramTest {
     #[allow(dead_code)]
     pub async fn with_signed_off_proposal(
         &mut self,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
         governance_cookie: &mut GovernanceCookie,
     ) -> Result<ProposalCookie, ProgramError> {
         let proposal_cookie = self
@@ -1180,7 +1197,7 @@ impl GovernanceProgramTest {
     #[allow(dead_code)]
     pub async fn with_proposal_using_instruction<F: Fn(&mut Instruction)>(
         &mut self,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
         governance_cookie: &mut GovernanceCookie,
         instruction_override: F,
     ) -> Result<ProposalCookie, ProgramError> {
@@ -1264,7 +1281,7 @@ impl GovernanceProgramTest {
     pub async fn with_signatory(
         &mut self,
         proposal_cookie: &ProposalCookie,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
     ) -> Result<SignatoryRecordCookie, ProgramError> {
         let signatory = Keypair::new();
 
@@ -1309,7 +1326,7 @@ impl GovernanceProgramTest {
     pub async fn remove_signatory(
         &mut self,
         proposal_cookie: &ProposalCookie,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
         signatory_record_cookie: &SignatoryRecordCookie,
     ) -> Result<(), ProgramError> {
         let remove_signatory_instruction = remove_signatory(
@@ -1381,6 +1398,7 @@ impl GovernanceProgramTest {
             &realm_cookie.address,
             &proposal_cookie.account.governance,
             &proposal_cookie.address,
+            &proposal_cookie.account.token_owner_record,
             &proposal_cookie.account.governing_token_mint,
         );
 
@@ -1394,7 +1412,7 @@ impl GovernanceProgramTest {
     pub async fn relinquish_vote(
         &mut self,
         proposal_cookie: &ProposalCookie,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
     ) -> Result<(), ProgramError> {
         self.relinquish_vote_using_instruction(
             proposal_cookie,
@@ -1408,7 +1426,7 @@ impl GovernanceProgramTest {
     pub async fn relinquish_vote_using_instruction<F: Fn(&mut Instruction)>(
         &mut self,
         proposal_cookie: &ProposalCookie,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
         instruction_override: F,
     ) -> Result<(), ProgramError> {
         let mut relinquish_vote_instruction = relinquish_vote(
@@ -1436,7 +1454,7 @@ impl GovernanceProgramTest {
     pub async fn cancel_proposal(
         &mut self,
         proposal_cookie: &ProposalCookie,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
     ) -> Result<(), ProgramError> {
         let cancel_proposal_instruction = cancel_proposal(
             &self.program_id,
@@ -1458,7 +1476,7 @@ impl GovernanceProgramTest {
     pub async fn with_cast_vote(
         &mut self,
         proposal_cookie: &ProposalCookie,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
         vote: Vote,
     ) -> Result<VoteRecordCookie, ProgramError> {
         let vote_instruction = cast_vote(
@@ -1466,6 +1484,7 @@ impl GovernanceProgramTest {
             &token_owner_record_cookie.account.realm,
             &proposal_cookie.account.governance,
             &proposal_cookie.address,
+            &proposal_cookie.account.token_owner_record,
             &token_owner_record_cookie.address,
             &token_owner_record_cookie.token_owner.pubkey(),
             &proposal_cookie.account.governing_token_mint,
@@ -1512,7 +1531,7 @@ impl GovernanceProgramTest {
     pub async fn with_set_governance_config_instruction(
         &mut self,
         proposal_cookie: &mut ProposalCookie,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
         governance_config: &GovernanceConfig,
     ) -> Result<ProposalInstructionCookie, ProgramError> {
         let mut set_governance_config_ix = set_governance_config(
@@ -1535,7 +1554,7 @@ impl GovernanceProgramTest {
         &mut self,
         governed_mint_cookie: &GovernedMintCookie,
         proposal_cookie: &mut ProposalCookie,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
         index: Option<u16>,
     ) -> Result<ProposalInstructionCookie, ProgramError> {
         let token_account_keypair = Keypair::new();
@@ -1570,7 +1589,7 @@ impl GovernanceProgramTest {
         &mut self,
         governed_token_cookie: &GovernedTokenCookie,
         proposal_cookie: &mut ProposalCookie,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
         index: Option<u16>,
     ) -> Result<ProposalInstructionCookie, ProgramError> {
         let token_account_keypair = Keypair::new();
@@ -1605,7 +1624,7 @@ impl GovernanceProgramTest {
         &mut self,
         governance_cookie: &GovernanceCookie,
         proposal_cookie: &mut ProposalCookie,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
     ) -> Result<ProposalInstructionCookie, ProgramError> {
         let program_buffer_keypair = Keypair::new();
         let buffer_authority_keypair = Keypair::new();
@@ -1671,7 +1690,7 @@ impl GovernanceProgramTest {
     pub async fn with_nop_instruction(
         &mut self,
         proposal_cookie: &mut ProposalCookie,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
         index: Option<u16>,
     ) -> Result<ProposalInstructionCookie, ProgramError> {
         // Create NOP instruction as a placeholder
@@ -1695,7 +1714,7 @@ impl GovernanceProgramTest {
     pub async fn with_instruction(
         &mut self,
         proposal_cookie: &mut ProposalCookie,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
         index: Option<u16>,
         instruction: &mut Instruction,
     ) -> Result<ProposalInstructionCookie, ProgramError> {
@@ -1764,7 +1783,7 @@ impl GovernanceProgramTest {
     pub async fn remove_instruction(
         &mut self,
         proposal_cookie: &mut ProposalCookie,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
         proposal_instruction_cookie: &ProposalInstructionCookie,
     ) -> Result<(), ProgramError> {
         let remove_instruction_instruction = remove_instruction(
@@ -1808,7 +1827,7 @@ impl GovernanceProgramTest {
     pub async fn flag_instruction_error(
         &mut self,
         proposal_cookie: &ProposalCookie,
-        token_owner_record_cookie: &TokeOwnerRecordCookie,
+        token_owner_record_cookie: &TokenOwnerRecordCookie,
         proposal_instruction_cookie: &ProposalInstructionCookie,
     ) -> Result<(), ProgramError> {
         let governance_authority = token_owner_record_cookie.get_governance_authority();
